==> python-unidecode-0.04.19-2-any.pkg.tar.xz: usr/lib/python3.5/site-packages/unidecode/x033.py <==
data = (
'apartment',    # 0x00
'alpha',    # 0x01
'ampere',    # 0x02
'are',    # 0x03
'inning',    # 0x04
'inch',    # 0x05
'won',    # 0x06
'escudo',    # 0x07
'acre',    # 0x08
'ounce',    # 0x09
'ohm',    # 0x0a
'kai-ri',    # 0x0b
'carat',    # 0x0c
'calorie',    # 0x0d
'gallon',    # 0x0e
'gamma',    # 0x0f
'giga',    # 0x10
'guinea',    # 0x11
'curie',    # 0x12
'guilder',    # 0x13
'kilo',    # 0x14
'kilogram',    # 0x15
'kilometer',    # 0x16
'kilowatt',    # 0x17
'gram',    # 0x18
'gram ton',    # 0x19
'cruzeiro',    # 0x1a
'krone',    # 0x1b
'case',    # 0x1c
'koruna',    # 0x1d
'co-op',    # 0x1e
'cycle',    # 0x1f
'centime',    # 0x20
'shilling',    # 0x21
'centi',    # 0x22
'cent',    # 0x23
'dozen',    # 0x24
'desi',    # 0x25
'dollar',    # 0x26
'ton',    # 0x27
'nano',    # 0x28
'knot',    # 0x29
'heights',    # 0x2a
'percent',    # 0x2b
'parts',    # 0x2c
'barrel',    # 0x2d
'piaster',    # 0x2e
'picul',    # 0x2f
'pico',    # 0x30
'building',    # 0x31
'farad',    # 0x32
'feet',    # 0x33
'bushel',    # 0x34
'franc',    # 0x35
'hectare',    # 0x36
'peso',    # 0x37
'pfennig',    # 0x38
'hertz',    # 0x39
'pence',    # 0x3a
'page',    # 0x3b
'beta',    # 0x3c
'point',    # 0x3d
'volt',    # 0x3e
'hon',    # 0x3f
'pound',    # 0x40
'hall',    # 0x41
'horn',    # 0x42
'micro',    # 0x43
'mile',    # 0x44
'mach',    # 0x45
'mark',    # 0x46
'mansion',    # 0x47
'micron',    # 0x48
'milli',    # 0x49
'millibar',    # 0x4a
'mega',    # 0x4b
'megaton',    # 0x4c
'meter',    # 0x4d
'yard',    # 0x4e
'yard',    # 0x4f
'yuan',    # 0x50
'liter',    # 0x51
'lira',    # 0x52
'rupee',    # 0x53
'ruble',    # 0x54
'rem',    # 0x55
'roentgen',    # 0x56
'watt',    # 0x57
'0h',    # 0x58
'1h',    # 0x59
'2h',    # 0x5a
'3h',    # 0x5b
'4h',    # 0x5c
'5h',    # 0x5d
'6h',    # 0x5e
'7h',    # 0x5f
'8h',    # 0x60
'9h',    # 0x61
'10h',    # 0x62
'11h',    # 0x63
'12h',    # 0x64
'13h',    # 0x65
'14h',    # 0x66
'15h',    # 0x67
'16h',    # 0x68
'17h',    # 0x69
'18h',    # 0x6a
'19h',    # 0x6b
'20h',    # 0x6c
'21h',    # 0x6d
'22h',    # 0x6e
'23h',    # 0x6f
'24h',    # 0x70
'HPA',    # 0x71
'da',    # 0x72
'AU',    # 0x73
'bar',    # 0x74
'oV',    # 0x75
'pc',    # 0x76
'[?]',    # 0x77
'[?]',    # 0x78
'[?]',    # 0x79
'[?]',    # 0x7a
'Heisei',    # 0x7b
'Syouwa',    # 0x7c
'Taisyou',    # 0x7d
'Meiji',    # 0x7e
'Inc.',    # 0x7f
'pA',    # 0x80
'nA',    # 0x81
'microamp',    # 0x82
'mA',    # 0x83
'kA',    # 0x84
'kB',    # 0x85
'MB',    # 0x86
'GB',    # 0x87
'cal',    # 0x88
'kcal',    # 0x89
'pF',    # 0x8a
'nF',    # 0x8b
'microFarad',    # 0x8c
'microgram',    # 0x8d
'mg',    # 0x8e
'kg',    # 0x8f
'Hz',    # 0x90
'kHz',    # 0x91
'MHz',    # 0x92
'GHz',    # 0x93
'THz',    # 0x94
'microliter',    # 0x95
'ml',    # 0x96
'dl',    # 0x97
'kl',    # 0x98
'fm',    # 0x99
'nm',    # 0x9a
'micrometer',    # 0x9b
'mm',    # 0x9c
'cm',    # 0x9d
'km',    # 0x9e
'mm^2',    # 0x9f
'cm^2',    # 0xa0
'm^2',    # 0xa1
'km^2',    # 0xa2
'mm^4',    # 0xa3
'cm^3',    # 0xa4
'm^3',    # 0xa5
'km^3',    # 0xa6
'm/s',    # 0xa7
'm/s^2',    # 0xa8
'Pa',    # 0xa9
'kPa',    # 0xaa
'MPa',    # 0xab
'GPa',    # 0xac
'rad',    # 0xad
'rad/s',    # 0xae
'rad/s^2',    # 0xaf
'ps',    # 0xb0
'ns',    # 0xb1
'microsecond',    # 0xb2
'ms',    # 0xb3
'pV',    # 0xb4
'nV',    # 0xb5
'microvolt',    # 0xb6
'mV',    # 0xb7
'kV',    # 0xb8
'MV',    # 0xb9
'pW',    # 0xba
'nW',    # 0xbb
'microwatt',    # 0xbc
'mW',    # 0xbd
'kW',    # 0xbe
'MW',    # 0xbf
'kOhm',    # 0xc0
'MOhm',    # 0xc1
'a.m.',    # 0xc2
'Bq',    # 0xc3
'cc',    # 0xc4
'cd',    # 0xc5
'C/kg',    # 0xc6
'Co.',    # 0xc7
'dB',    # 0xc8
'Gy',    # 0xc9
'ha',    # 0xca
'HP',    # 0xcb
'in',    # 0xcc
'K.K.',    # 0xcd
'KM',    # 0xce
'kt',    # 0xcf
'lm',    # 0xd0
'ln',    # 0xd1
'log',    # 0xd2
'lx',    # 0xd3
'mb',    # 0xd4
'mil',    # 0xd5
'mol',    # 0xd6
'pH',    # 0xd7
'p.m.',    # 0xd8
'PPM',    # 0xd9
'PR',    # 0xda
'sr',    # 0xdb
'Sv',    # 0xdc
'Wb',    # 0xdd
'[?]',    # 0xde
'[?]',    # 0xdf
'1d',    # 0xe0
'2d',    # 0xe1
'3d',    # 0xe2
'4d',    # 0xe3
'5d',    # 0xe4
'6d',    # 0xe5
'7d',    # 0xe6
'8d',    # 0xe7
'9d',    # 0xe8
'10d',    # 0xe9
'11d',    # 0xea
'12d',    # 0xeb
'13d',    # 0xec
'14d',    # 0xed
'15d',    # 0xee
'16d',    # 0xef
'17d',    # 0xf0
'18d',    # 0xf1
'19d',    # 0xf2
'20d',    # 0xf3
'21d',    # 0xf4
'22d',    # 0xf5
'23d',    # 0xf6
'24d',    # 0xf7
'25d',    # 0xf8
'26d',    # 0xf9
'27d',    # 0xfa
'28d',    # 0xfb
'29d',    # 0xfc
'30d',    # 0xfd
'31d',    # 0xfe
)

==> python-unidecode-0.04.21-1-any.pkg.tar.xz: usr/lib/python3.6/site-packages/unidecode/x033.py <==
data = (
'apartment',    # 0x00
'alpha',    # 0x01
'ampere',    # 0x02
'are',    # 0x03
'inning',    # 0x04
'inch',    # 0x05
'won',    # 0x06
'escudo',    # 0x07
'acre',    # 0x08
'ounce',    # 0x09
'ohm',    # 0x0a
'kai-ri',    # 0x0b
'carat',    # 0x0c
'calorie',    # 0x0d
'gallon',    # 0x0e
'gamma',    # 0x0f
'giga',    # 0x10
'guinea',    # 0x11
'curie',    # 0x12
'guilder',    # 0x13
'kilo',    # 0x14
'kilogram',    # 0x15
'kilometer',    # 0x16
'kilowatt',    # 0x17
'gram',    # 0x18
'gram ton',    # 0x19
'cruzeiro',    # 0x1a
'krone',    # 0x1b
'case',    # 0x1c
'koruna',    # 0x1d
'co-op',    # 0x1e
'cycle',    # 0x1f
'centime',    # 0x20
'shilling',    # 0x21
'centi',    # 0x22
'cent',    # 0x23
'dozen',    # 0x24
'desi',    # 0x25
'dollar',    # 0x26
'ton',    # 0x27
'nano',    # 0x28
'knot',    # 0x29
'heights',    # 0x2a
'percent',    # 0x2b
'parts',    # 0x2c
'barrel',    # 0x2d
'piaster',    # 0x2e
'picul',    # 0x2f
'pico',    # 0x30
'building',    # 0x31
'farad',    # 0x32
'feet',    # 0x33
'bushel',    # 0x34
'franc',    # 0x35
'hectare',    # 0x36
'peso',    # 0x37
'pfennig',    # 0x38
'hertz',    # 0x39
'pence',    # 0x3a
'page',    # 0x3b
'beta',    # 0x3c
'point',    # 0x3d
'volt',    # 0x3e
'hon',    # 0x3f
'pound',    # 0x40
'hall',    # 0x41
'horn',    # 0x42
'micro',    # 0x43
'mile',    # 0x44
'mach',    # 0x45
'mark',    # 0x46
'mansion',    # 0x47
'micron',    # 0x48
'milli',    # 0x49
'millibar',    # 0x4a
'mega',    # 0x4b
'megaton',    # 0x4c
'meter',    # 0x4d
'yard',    # 0x4e
'yard',    # 0x4f
'yuan',    # 0x50
'liter',    # 0x51
'lira',    # 0x52
'rupee',    # 0x53
'ruble',    # 0x54
'rem',    # 0x55
'roentgen',    # 0x56
'watt',    # 0x57
'0h',    # 0x58
'1h',    # 0x59
'2h',    # 0x5a
'3h',    # 0x5b
'4h',    # 0x5c
'5h',    # 0x5d
'6h',    # 0x5e
'7h',    # 0x5f
'8h',    # 0x60
'9h',    # 0x61
'10h',    # 0x62
'11h',    # 0x63
'12h',    # 0x64
'13h',    # 0x65
'14h',    # 0x66
'15h',    # 0x67
'16h',    # 0x68
'17h',    # 0x69
'18h',    # 0x6a
'19h',    # 0x6b
'20h',    # 0x6c
'21h',    # 0x6d
'22h',    # 0x6e
'23h',    # 0x6f
'24h',    # 0x70
'hPa',    # 0x71
'da',    # 0x72
'AU',    # 0x73
'bar',    # 0x74
'oV',    # 0x75
'pc',    # 0x76
'dm',    # 0x77
'dm^2',    # 0x78
'dm^3',    # 0x79
'IU',    # 0x7a
'Heisei',    # 0x7b
'Syouwa',    # 0x7c
'Taisyou',    # 0x7d
'Meiji',    # 0x7e
'Inc.',    # 0x7f
'pA',    # 0x80
'nA',    # 0x81
'microamp',    # 0x82
'mA',    # 0x83
'kA',    # 0x84
'kB',    # 0x85
'MB',    # 0x86
'GB',    # 0x87
'cal',    # 0x88
'kcal',    # 0x89
'pF',    # 0x8a
'nF',    # 0x8b
'microFarad',    # 0x8c
'microgram',    # 0x8d
'mg',    # 0x8e
'kg',    # 0x8f
'Hz',    # 0x90
'kHz',    # 0x91
'MHz',    # 0x92
'GHz',    # 0x93
'THz',    # 0x94
'microliter',    # 0x95
'ml',    # 0x96
'dl',    # 0x97
'kl',    # 0x98
'fm',    # 0x99
'nm',    # 0x9a
'micrometer',    # 0x9b
'mm',    # 0x9c
'cm',    # 0x9d
'km',    # 0x9e
'mm^2',    # 0x9f
'cm^2',    # 0xa0
'm^2',    # 0xa1
'km^2',    # 0xa2
'mm^3',    # 0xa3
'cm^3',    # 0xa4
'm^3',    # 0xa5
'km^3',    # 0xa6
'm/s',    # 0xa7
'm/s^2',    # 0xa8
'Pa',    # 0xa9
'kPa',    # 0xaa
'MPa',    # 0xab
'GPa',    # 0xac
'rad',    # 0xad
'rad/s',    # 0xae
'rad/s^2',    # 0xaf
'ps',    # 0xb0
'ns',    # 0xb1
'microsecond',    # 0xb2
'ms',    # 0xb3
'pV',    # 0xb4
'nV',    # 0xb5
'microvolt',    # 0xb6
'mV',    # 0xb7
'kV',    # 0xb8
'MV',    # 0xb9
'pW',    # 0xba
'nW',    # 0xbb
'microwatt',    # 0xbc
'mW',    # 0xbd
'kW',    # 0xbe
'MW',    # 0xbf
'kOhm',    # 0xc0
'MOhm',    # 0xc1
'a.m.',    # 0xc2
'Bq',    # 0xc3
'cc',    # 0xc4
'cd',    # 0xc5
'C/kg',    # 0xc6
'Co.',    # 0xc7
'dB',    # 0xc8
'Gy',    # 0xc9
'ha',    # 0xca
'HP',    # 0xcb
'in',    # 0xcc
'K.K.',    # 0xcd
'KM',    # 0xce
'kt',    # 0xcf
'lm',    # 0xd0
'ln',    # 0xd1
'log',    # 0xd2
'lx',    # 0xd3
'mb',    # 0xd4
'mil',    # 0xd5
'mol',    # 0xd6
'pH',    # 0xd7
'p.m.',    # 0xd8
'PPM',    # 0xd9
'PR',    # 0xda
'sr',    # 0xdb
'Sv',    # 0xdc
'Wb',    # 0xdd
'[?]',    # 0xde
'[?]',    # 0xdf
'1d',    # 0xe0
'2d',    # 0xe1
'3d',    # 0xe2
'4d',    # 0xe3
'5d',    # 0xe4
'6d',    # 0xe5
'7d',    # 0xe6
'8d',    # 0xe7
'9d',    # 0xe8
'10d',    # 0xe9
'11d',    # 0xea
'12d',    # 0xeb
'13d',    # 0xec
'14d',    # 0xed
'15d',    # 0xee
'16d',    # 0xef
'17d',    # 0xf0
'18d',    # 0xf1
'19d',    # 0xf2
'20d',    # 0xf3
'21d',    # 0xf4
'22d',    # 0xf5
'23d',    # 0xf6
'24d',    # 0xf7
'25d',    # 0xf8
'26d',    # 0xf9
'27d',    # 0xfa
'28d',    # 0xfb
'29d',    # 0xfc
'30d',    # 0xfd
'31d',    # 0xfe
'gal',    # 0xff
)
